@@ -717,11 +717,10 @@ QVariant KDirModel::data(const QModelIndex &index, int role) const
             case Name:
                 return item.text();
             case Size:
-                // Filesize in bytes (type qulonglong)
-                return item.size();
+                return KIO::convertSize(item.size()); // size formatted as QString
             case ModifiedTime: {
                 QDateTime dt = item.time(KFileItem::ModificationTime);
-                return dt.toString();
+                return dt.toString(Qt::SystemLocaleShortDate);
             }
             case Permissions:
                 return item.permissionsString();
@@ -1022,7 +1021,7 @@ KFileItem KDirModel::itemForIndex(const QModelIndex &index) const
     }
 }
 
-#ifndef KDE_NO_DEPRECATED
+#ifndef KIOWIDGETS_NO_DEPRECATED
 QModelIndex KDirModel::indexForItem(const KFileItem *item) const
 {
     // Note that we can only use the URL here, not the pointer.
